@@ -24,12 +24,13 @@ from gettext import gettext as _
 import gtk
 import gtk.glade
 
-from ontv import NAME, GLADE_DIR, LOCALE_DIR, PIXMAPS_DIR
+from ontv import NAME, DATA_DIR, LOCALE_DIR, PIXMAPS_DIR
 
 gtk.glade.bindtextdomain(NAME.lower(), LOCALE_DIR)
 
-glade_file = os.path.join(GLADE_DIR, "ontv.glade")
-xml = gtk.glade.XML(glade_file, domain=NAME.lower())
+glade_file = os.path.join(DATA_DIR, "ontv.glade")
+
+logo_downloading_file = os.path.join(DATA_DIR, "ontv-logo-downloading.png")
 
 icon_file = os.path.join(PIXMAPS_DIR, "ontv.png")
 icon = gtk.gdk.pixbuf_new_from_file(icon_file)
@@ -41,6 +42,12 @@ def has_selection(treeview):
         return True
     return False
 
+def get_selected_value(treeview):
+    selection = treeview.get_selection()
+    (model, iter) = selection.get_selected()
+    value = model.get_value(iter, 0)
+    return value
+
 def queue_resize(treeview):
     columns = treeview.get_columns()
     for column in columns:
