@@ -16,7 +16,7 @@
 
 # You should have received a copy of the GNU General Public License
 # along with ontv; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 from gettext import gettext as _
 
@@ -24,13 +24,15 @@ import gtk
 import gobject
 
 import GUI
+from ProgramDialog import ProgramDialog
 from Reminders import Reminder
+from ontv import NAME
 
 TIMEOUT = 100
 
 class SearchDialog:
     def __init__(self, xmltvfile, reminders):
-        xmltvfile.connect("loaded", self.__xmltvfile_loaded)
+        xmltvfile.connect("loading-done", self.__xmltvfile_loading_done)
         self.reminders = reminders
 
         self.__get_widgets()
@@ -44,15 +46,17 @@ class SearchDialog:
         self.__timeout_id = 0
 
     def __get_widgets(self):
-        self.dialog = GUI.xml.get_widget("search_dialog")
-        self.add_reminder_button2 = GUI.xml.get_widget("add_reminder_button2")
-        self.closebutton = GUI.xml.get_widget("closebutton2")
+        xml = gtk.glade.XML(GUI.glade_file, domain=NAME.lower())
 
-        self.search_label = GUI.xml.get_widget("search_label")
-        self.search_entry = GUI.xml.get_widget("search_entry")
-        self.channels_combobox = GUI.xml.get_widget("channels_combobox")
+        self.dialog = xml.get_widget("search_dialog")
+        self.details_button = xml.get_widget("details_button")
+        self.closebutton = xml.get_widget("search_closebutton")
 
-        self.search_treeview = GUI.xml.get_widget("search_treeview")
+        self.search_label = xml.get_widget("search_label")
+        self.search_entry = xml.get_widget("search_entry")
+        self.channels_combobox = xml.get_widget("channels_combobox")
+
+        self.search_treeview = xml.get_widget("search_treeview")
 
     def __make_channels_combobox(self):
         crt = gtk.CellRendererText()
@@ -77,6 +81,17 @@ class SearchDialog:
         program_column.set_cell_data_func(crtext, self.__crtext_cell_data_func)
         self.search_treeview.append_column(program_column)
 
+        self.search_treeview_menu = gtk.Menu()
+        self.details_imi = gtk.ImageMenuItem(gtk.STOCK_INFO)
+        self.details_imi.child.set_markup_with_mnemonic(_("_Details"))
+        self.details_imi.show()
+        self.search_treeview_menu.append(self.details_imi)
+
+        self.add_reminder_imi = gtk.ImageMenuItem("gnome-stock-timer")
+        self.add_reminder_imi.child.set_markup_with_mnemonic(_("_Add reminder"))
+        self.add_reminder_imi.show()
+        self.search_treeview_menu.append(self.add_reminder_imi)
+
     def __crt_cell_data_func(self, column, cell, model, iter):
         program = model.get_value(iter, 0)
         markup = "<b>%s-%s</b>\n<i>%s</i>"
@@ -90,21 +105,25 @@ class SearchDialog:
                                       program.channel.markup_escaped_name)
 
     def __connect_widgets(self):
-        self.dialog.connect("close", self.__dialog_close)
-        self.closebutton.connect("clicked", self.__closebutton_click)
+        self.dialog.connect("close", self.__close_dialog)
+        self.closebutton.connect("clicked", self.__close_dialog)
 
         self.search_entry.connect("changed", self.__search_entry_changed)
 
         selection = self.search_treeview.get_selection()
         selection.connect("changed", self.__search_treeview_selection_changed)
+        self.search_treeview.connect("row-activated",
+                                     self.__search_treeview_row_activated)
+        self.search_treeview.connect("button-press-event",
+                                     self.__search_treeview_button_press,
+                                     self.search_treeview_menu)
+        self.details_imi.connect("activate", self.__details_imi_activate)
+        self.add_reminder_imi.connect("activate",
+                                      self.__add_reminder_imi_activate)
 
-        self.add_reminder_button2.connect("clicked",
-                                         self.__add_reminder_button_clicked)
+        self.details_button.connect("clicked", self.__details_button_clicked)
 
-    def __dialog_close(self, dialog):
-        self.dialog.hide()
-
-    def __closebutton_click(self, button):
+    def __close_dialog(self, widget):
         self.dialog.hide()
 
     def __search_entry_changed(self, entry):
@@ -144,28 +163,54 @@ class SearchDialog:
     def __search_treeview_selection_changed(self, selection):
         (search_model, search_iter) = selection.get_selected()
         if search_iter:
+            self.details_button.set_sensitive(True)
             program = search_model.get_value(search_iter, 0)
             reminder = Reminder(program.title,
                                 program.channel.markup_escaped_name)
-            if not reminder in self.reminders.reminders and \
-               not self.add_reminder_button2.props.sensitive:
-                self.add_reminder_button2.set_sensitive(True)
+            if not reminder in self.reminders.reminders:
+                self.add_reminder_imi.set_sensitive(True)
             else:
-                self.add_reminder_button2.set_sensitive(False)
+                self.add_reminder_imi.set_sensitive(False)
         else:
-            self.add_reminder_button2.set_sensitive(False)
+            self.details_button.set_sensitive(False)
+            self.add_reminder_imi.set_sensitive(False)
 
-    def __add_reminder_button_clicked(self, button):
-        selection = self.search_treeview.get_selection()
-        (search_model, search_iter) = selection.get_selected()
-        program = search_model.get_value(search_iter, 0)
+    def __search_treeview_row_activated(self, treeview, path, column):
+        self.details_button.emit("clicked")
+
+    def __search_treeview_button_press(self, treeview, event, menu):
+        if event.type == gtk.gdk.BUTTON_PRESS and event.button == 3:
+            search_model = treeview.get_model()
+            path = treeview.get_path_at_pos(int(event.x), int(event.y))[0]
+            program = search_model[path][0]
+            if program.description and program.description != "":
+                self.details_imi.set_sensitive(True)
+            else:
+                self.details_imi.set_sensitive(False)
+
+            menu.popup(None, None, None, event.button, event.time)
+
+    def __details_imi_activate(self, menuitem):
+        program = GUI.get_selected_value(self.search_treeview)
+        self.__show_program_dialog(program)
+
+    def __add_reminder_imi_activate(self, menuitem):
+        program = GUI.get_selected_value(self.search_treeview)
         reminder = Reminder(program.title, program.channel.markup_escaped_name)
         if self.reminders.add(reminder):
             self.reminders_model.append([reminder])
             self.reminders.save()
-            self.add_reminder_button2.set_sensitive(False)
+            self.add_reminder_imi.set_sensitive(False)
 
-    def __xmltvfile_loaded(self, xmltvfile, listings):
+    def __details_button_clicked(self, button):
+        program = GUI.get_selected_value(self.search_treeview)
+        self.__show_program_dialog(program)
+
+    def __show_program_dialog(self, program):
+        pd = ProgramDialog(program)
+        pd.show()
+
+    def __xmltvfile_loading_done(self, xmltvfile, listings):
         if listings:
             self.listings = listings
             self.search_entry.emit("changed")
@@ -180,9 +225,17 @@ class SearchDialog:
             channels_iter = channels_model.iter_next(channels_iter)
 
     def show(self, uicomponent=None, verb=None):
+        self.present()
+
+    def present(self, time=None):
         self.search_treeview.set_cursor(0)
         self.search_entry.grab_focus()
         self.dialog.grab_focus()
-        self.dialog.show()
+        if time:
+            self.dialog.present_with_time(time)
+            # Ugly, but the only way I could get it to work correct
+            self.dialog.present_with_time(time)
+        else:
+            self.dialog.present()
 
 # vim: set sw=4 et sts=4 tw=79 fo+=l:
